@@ -1,4 +1,6 @@
 from typing import Union
+
+from learning_loop_node.detector.segmentation_detection import SegmentationDetection
 from ..detector.box_detection import BoxDetection
 from ..detector.point_detection import PointDetection
 from datetime import datetime, timedelta
@@ -6,7 +8,7 @@ from datetime import datetime, timedelta
 
 class Observation():
 
-    def __init__(self, detection: Union[BoxDetection, PointDetection]):
+    def __init__(self, detection: Union[BoxDetection, PointDetection, SegmentationDetection]):
         self.detection = detection
         self.last_seen = datetime.now()
 
